]> git.tdb.fi Git - ext/subsurface.git/commitdiff
Rename the project 'subsurface'
authorLinus Torvalds <torvalds@linux-foundation.org>
Thu, 15 Sep 2011 16:43:14 +0000 (09:43 -0700)
committerLinus Torvalds <torvalds@linux-foundation.org>
Thu, 15 Sep 2011 16:43:14 +0000 (09:43 -0700)
I never really liked 'diveclog' as a name - it's not like the C part is
all that important.  And while I could try to just make up another slang
word for despicable person (in the tradition of naming all my projects
after myself), I just can't see it.

So let's just call it "subsurface".

Signed-off-by: Linus Torvalds <torvalds@linux-foundation.org>
.gitignore
Makefile
README
libdivecomputer.c
main.c
parse-xml.c
save-xml.c

index aeb949b3d83246d568ac4907e2c68c3b0893884b..14742cce932712e1777fb34640dfda7aa33ffab0 100644 (file)
@@ -1,2 +1,2 @@
 *.o
-/divelog
+/subsurface
index c78b806bb259968493b23b9e7048daa4e6f60ba7..fb84494fc970ff16dc393474c901895609c1b58a 100644 (file)
--- a/Makefile
+++ b/Makefile
@@ -8,8 +8,8 @@ LIBDIVECOMPUTERARCHIVE = $(LIBDIVECOMPUTERDIR)/lib/libdivecomputer.a
 OBJS = main.o dive.o profile.o info.o equipment.o divelist.o \
        parse-xml.o save-xml.o libdivecomputer.o print.o uemis.o
 
-divelog: $(OBJS)
-       $(CC) $(LDFLAGS) -o divelog $(OBJS) \
+subsurface: $(OBJS)
+       $(CC) $(LDFLAGS) -o subsurface $(OBJS) \
                `xml2-config --libs` \
                `pkg-config --libs gtk+-2.0 glib-2.0 gconf-2.0` \
                $(LIBDIVECOMPUTERARCHIVE)
diff --git a/README b/README
index 5947febb702cd072553b6a686121a2ff3cfb3b14..35c9c6913b5eda0422f0407f94f83b26ba3ecbaf 100644 (file)
--- a/README
+++ b/README
@@ -18,7 +18,7 @@ You also need to have libdivecomputer installed, which goes something like this:
 Usage:
 
        make
-       ./divelog dives/*.xml
+       ./subsurface dives/*.xml
 
 to see my dives (with no notes or commentary).
 
@@ -26,15 +26,15 @@ Or, if you have a dive computer supported by libdivecomputer (and
 connected to /dev/ttyUSB0), you can just do
 
        make
-       ./divelog
+       ./subsurface
 
 and select "Import" from the File menu, tell it what dive computer you
 have, and hit "OK".
 
 There's a lot of duplicates in the XML files that come as an example,
-and divelog will de-duplicate the ones that are exactly the same (just
-because they were imported multiple times).  But at least two of the
-dives have duplicates that were edited by Dirk in the Suunto Dive
+and subsurface will de-duplicate the ones that are exactly the same
+(just because they were imported multiple times).  But at least two of
+the dives have duplicates that were edited by Dirk in the Suunto Dive
 Manager, so they don't trigger the "exact duplicates" match.
 
 WARNING! I wasn't kidding when I said that I've done this by reading
index 2b62fa3652b58e556684ca87df48f7364573a6a6..49c4f3695da6ca60bf3d42904d26c3f1b61e2588 100644 (file)
@@ -40,7 +40,7 @@ static void error(const char *fmt, ...)
 
        va_start(args, fmt);
        error = g_error_new_valist(
-               g_quark_from_string("divelog"),
+               g_quark_from_string("subsurface"),
                DIVE_ERROR_PARSE, fmt, args);
        va_end(args);
        report_error(error);
diff --git a/main.c b/main.c
index c7daf19d73aa927932864d67c0432438adeee3ea..e6f58ce5bf6325dbc78792d32ccb9f64cbcb2c63 100644 (file)
--- a/main.c
+++ b/main.c
@@ -19,7 +19,7 @@ struct DiveList   dive_list;
 GConfClient *gconf;
 struct units output_units;
 
-#define GCONF_NAME(x) "/apps/diveclog/" #x
+#define GCONF_NAME(x) "/apps/subsurface/" #x
 
 static int sortfn(const void *_a, const void *_b)
 {
index 82149cf8aca5c7c76cf7b5bc5a6b012f1ea4d1ef..6bb78fdf6077e1db2a85ee6ee194e5793c8ae802 100644 (file)
@@ -521,7 +521,7 @@ static void fahrenheit(char *buffer, void *_temperature)
  * pressures are in PSI. But the tank working pressure is in
  * bar. WTF^2?
  *
* Crazy stuff like this is why diveclog has everything in
  * these inconvenient typed structures, and you have to say
  * "pressure->mbar" to get the actual value. Exactly so that
  * you can never have unit confusion.
@@ -1357,7 +1357,7 @@ void parse_xml_file(const char *filename, GError **error)
                fprintf(stderr, "Failed to parse '%s'.\n", filename);
                if (error != NULL)
                {
-                       *error = g_error_new(g_quark_from_string("divelog"),
+                       *error = g_error_new(g_quark_from_string("subsurface"),
                                             DIVE_ERROR_PARSE,
                                             "Failed to parse '%s'",
                                             filename);
index 47a8a7ebb23767de9e8202ca90e3b101a142bacd..42bd17e9faae65228fe6f759405c2e4da6731e91 100644 (file)
@@ -236,7 +236,7 @@ void save_dives(const char *filename)
        /* Flush any edits of current dives back to the dives! */
        update_dive(current_dive);
 
-       fprintf(f, "<dives>\n<program name='diveclog' version='%d'></program>\n", VERSION);
+       fprintf(f, "<dives>\n<program name='subsurface' version='%d'></program>\n", VERSION);
        for (i = 0; i < dive_table.nr; i++)
                save_dive(f, get_dive(i));
        fprintf(f, "</dives>\n");
@@ -521,7 +521,7 @@ static void fahrenheit(char *buffer, void *_temperature)
  * bar. WTF^2?
  *
- * Crazy stuff like this is why diveclog has everything in
+ * Crazy stuff like this is why subsurface has everything in
  * these inconvenient typed structures, and you have to say
  * "pressure->mbar" to get the actual value. Exactly so that